From f8c4bee3a4223d77f44c961c4eab9afa4cb1345b Mon Sep 17 00:00:00 2001
From: Le Wang <le.wang@agworld.com.au>
Date: Fri, 14 Dec 2012 06:46:15 +0800
Subject: [PATCH 4/5] add org-src-error error-condition

- This makes code more testable, because we can expect org specific
  errors instead of the generic error.
---
 lisp/org-src.el | 15 ++++++++++-----
 1 file changed, 10 insertions(+), 5 deletions(-)

diff --git a/lisp/org-src.el b/lisp/org-src.el
index 97f473a..ad6ec60 100644
--- a/lisp/org-src.el
+++ b/lisp/org-src.el
@@ -192,6 +192,11 @@ the existing edit buffer.")
 
 (defvar org-src-babel-info nil)
 
+(put 'org-src-error
+     'error-conditions
+     '(error org-src-error))
+(put 'org-src-error 'error-message "Org Src Error")
+
 (define-minor-mode org-src-mode
   "Minor mode for language major mode buffers generated by org.
 This minor mode is turned on in two situations:
@@ -227,7 +232,7 @@ buffer."
 		  (goto-char beg)
 		  (insert "\n")
 		  (org-edit-src-find-region-and-lang))
-	      (error "Point not in src block."))))
+	      (signal 'org-src-error '("Point not in src block.")))))
 	 (full-info (org-babel-get-src-block-info 'light))
 	 (org-mode-p (derived-mode-p 'org-mode)) ;; derived-mode-p is reflexive
 	 (beg (make-marker))
@@ -280,7 +285,7 @@ buffer."
 			 (table-recognize)
 			 (org-set-local 'org-edit-src-content-indentation 0))))
       (unless (functionp lang-f)
-	(error "No such language mode: %s" lang-f))
+	(signal 'org-src-error "No such language mode: %s" lang-f))
       (save-excursion
 	(if (> (point) end) (goto-char end))
 	(setq line (org-current-line)
@@ -322,7 +327,7 @@ buffer."
 	  (condition-case e
 	      (funcall lang-f)
 	    (error
-	     (error "Language mode `%s' fails with: %S" lang-f (nth 1 e)))))
+	     (signal 'org-src-error "Language mode `%s' fails with: %S" lang-f (nth 1 e)))))
 	(dolist (pair transmitted-variables)
 	  (org-set-local (car pair) (cadr pair)))
 	;; Remove protecting commas from visible part of buffer.
@@ -353,7 +358,7 @@ buffer."
   (mouse-set-point e)
   (let ((buf (get-char-property (point) 'edit-buffer)))
     (if buf (org-src-switch-to-buffer buf 'continue)
-      (error "Something is wrong here"))))
+      (signal 'org-src-error "Something is wrong here"))))
 
 (defun org-src-switch-to-buffer (buffer context)
   (case org-src-window-setup
@@ -636,7 +641,7 @@ with \",*\", \",#+\", \",,*\" and \",,#+\"."
   "Exit special edit and protect problematic lines."
   (interactive)
   (unless (org-bound-and-true-p org-edit-src-from-org-mode)
-    (error "This is not a sub-editing buffer, something is wrong"))
+    (signal 'org-src-error "This is not a sub-editing buffer, something is wrong"))
   (widen)
   (let* ((beg org-edit-src-beg-marker)
 	 (end org-edit-src-end-marker)
-- 
1.7.11.4

